"""Miscellaneous module."""

from .download import wget
from .list import rindex


__all__ = [
    'wget',
    'rindex',
]
